@@ -1,8 +1,8 @@
 import pytest
 from click.testing import CliRunner
 
-from openapi_python_generator.__main__ import main
-from openapi_python_generator.common import HTTPLibrary
+from ab_openapi_python_generator.__main__ import main
+from ab_openapi_python_generator.common import HTTPLibrary
 from tests.conftest import test_data_folder
 from tests.conftest import test_result_path
 
