@@ -1,6 +1,6 @@
 from openapi_pydantic.v3 import OpenAPI
 
-from openapi_python_generator.language_converters.python.api_config_generator import (
+from ab_openapi_python_generator.language_converters.python.api_config_generator import (
     generate_api_config,
 )
 
