@@ -9,9 +9,9 @@ from pathlib import Path
 
 import pytest
 
-from openapi_python_generator.generate_data import generate_data
-from openapi_python_generator.common import HTTPLibrary
-from openapi_python_generator.parsers import parse_openapi_3_1
+from ab_openapi_python_generator.generate_data import generate_data
+from ab_openapi_python_generator.common import HTTPLibrary
+from ab_openapi_python_generator.parsers import parse_openapi_3_1
 
 
 class TestOpenAPI31Completeness:
