@@ -1,6 +1,6 @@
 from openapi_pydantic.v3 import Response, MediaType, Schema, DataType, Operation
-from openapi_python_generator.language_converters.python import service_generator
-from openapi_python_generator.models import OpReturnType
+from ab_openapi_python_generator.language_converters.python import service_generator
+from ab_openapi_python_generator.models import OpReturnType
 
 
 def test_is_schema_type_helper():
